@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -9,8 +9,8 @@ our @EXPORT_OK = qw(
     north east south west handson
     layout checkerboard animate
     chess checkers conway sudoku
-    calculator dk shroom
-    calendar banner maze
+    calculator calendar banner maze
+    beadwork
 );
 
 use Clone;
@@ -40,8 +40,7 @@ sub calendar        { Spreadsheet::HTML::Presets::calendar(         @_ ) }
 sub animate         { Spreadsheet::HTML::Presets::Animate::animate( @_ ) }
 sub maze            { Spreadsheet::HTML::Presets::maze(             @_ ) }
 sub banner          { Spreadsheet::HTML::Presets::banner(           @_ ) }
-sub dk              { Spreadsheet::HTML::Presets::dk(               @_ ) }
-sub shroom          { Spreadsheet::HTML::Presets::shroom(           @_ ) }
+sub beadwork        { Spreadsheet::HTML::Presets::Beadwork::beadwork( @_ ) }
 
 sub generate {
     my %args = _process( @_ );
@@ -97,7 +96,8 @@ sub generate {
                 $new_args{$_} = { %{ $new_args{$_} || {} }, %{ $args{$_} || {} } };
             }
         }
-        return $js . _make_table( _process( %new_args ) );
+        my $table = _make_table( _process( %new_args ) );
+        return wantarray ? ( $table, $js ) : $js . $table;
     }
 
     return _make_table( %args );
@@ -371,6 +371,22 @@ existing tables from Excel, HTML, JSON, CSV and YAML files.
 
 THIS MODULE IS AN ALPHA RELEASE! Although we are very close to BETA.
 
+=head1 CLI TOOL
+
+A command line interface tool is available for you to quickly
+generate tables without writing a script: C<mktable>
+
+  $ mktable landscape --param file=data.xls --param preserve=1 > out.html
+
+If you have L<HTML::Display> install, you can direct the output to
+your default browser:
+
+  $ mktable sudoku --display
+
+  $ mktable landscape --param data=[[a..d],[1..4],[5..8]] --display
+
+  $ mktable conway --param data=[1..300] --param wrap=20 --param matrix=1 --display
+
 =head1 METHODS
 
 All methods (except C<new>) are exportable as functions. They all
@@ -536,7 +552,7 @@ to insert into to.
 
 =item * C<encodes>
 
-HTML Encode contents of <tr> and/or <td> tags. Defaults to
+HTML Encode contents of <th> and/or <td> tags. Defaults to
 empty string which performs no encoding of entities. Pass
 a string like '<>&=' to perform encoding on any characters
 found.  If the value is C<undef> then all unsafe characters
@@ -587,6 +603,10 @@ Render the table with without the headings row at all.
 The first row after the headings is still C<-r1>, thus
 any reference to C<headings> will be discarded too.
 
+=item * C<animate: 0 or 1>
+
+Animate the table cells. See *L<Spreadsheet::HTML::Presets::Animate>.
+
 =item * C<headings>
 
 Apply callback subroutine to each cell in headings row.
@@ -762,9 +782,7 @@ with little to no additional coding.
 
 =item * C<checkers( %params )>
 
-=item * C<dk( %params )>
-
-=item * C<shroom( %params )>
+=item * C<beadwork( %params )>
 
 =back
 
